@@ -37,6 +37,9 @@ ExportImageDialogUI::ExportImageDialogUI(QWidget *parent)
 ExportImageDialog::ExportImageDialog(const QString &url, const QSize &size, ImageExporter *imgExporter)
     : QDialog((QWidget*) KStars::Instance()), m_KStars(KStars::Instance()), m_Url(url), m_Size(size)
 {
+#ifdef Q_OS_OSX
+        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+#endif
     m_DialogUI = new ExportImageDialogUI(this);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
