@@ -34,7 +34,8 @@ SequenceJob::SequenceJob()
 {
     statusStrings = QStringList() << i18n("Idle") << i18n("In Progress") << i18n("Error") << i18n("Aborted") << i18n("Complete");
     status = JOB_IDLE;
-    exposure=count=delay=frameType=targetFilter=isoIndex=-1;
+    exposure=count=delay=targetFilter=isoIndex=-1;
+    frameType=FRAME_LIGHT;
     currentTemperature=targetTemperature=INVALID_TEMPERATURE;
     captureFilter=FITS_NONE;
     preview=false;
@@ -50,6 +51,7 @@ SequenceJob::SequenceJob()
     calibrationSettings.flatFieldSource   = SOURCE_MANUAL;
     calibrationSettings.flatFieldDuration = DURATION_MANUAL;
     calibrationSettings.targetADU         = 0;
+    calibrationSettings.targetADUTolerance= 250;
     calibrationSettings.preMountPark           = false;
     calibrationSettings.preDomePark            = false;
 
@@ -172,28 +174,32 @@ SequenceJob::CAPTUREResult SequenceJob::capture(bool noCaptureFilter)
             activeChip->setISOIndex(isoIndex);
    }
 
-   if ((w > 0 && h > 0) && activeChip->canSubframe() && activeChip->setFrame(x, y, w, h) == false)
+   // Only attempt to set ROI and Binning if CCD transfer format is FITS
+   if (activeCCD->getTransferFormat() == ISD::CCD::FORMAT_FITS)
    {
-        status = JOB_ERROR;
+       if ((w > 0 && h > 0) && activeChip->canSubframe() && activeChip->setFrame(x, y, w, h) == false)
+       {
+            status = JOB_ERROR;
 
-        if (preview == false && statusCell)
-            statusCell->setText(statusStrings[status]);
+            if (preview == false && statusCell)
+                statusCell->setText(statusStrings[status]);
 
-        return CAPTURE_FRAME_ERROR;
+            return CAPTURE_FRAME_ERROR;
 
+       }
+
+       if (activeChip->canBin() && activeChip->setBinning(binX, binY) == false)
+       {
+           status = JOB_ERROR;
+
+           if (preview == false && statusCell)
+               statusCell->setText(statusStrings[status]);
+
+           return CAPTURE_BIN_ERROR;
+       }
    }
 
-   if (activeChip->canBin() && activeChip->setBinning(binX, binY) == false)
-   {
-       status = JOB_ERROR;
-
-       if (preview == false && statusCell)
-           statusCell->setText(statusStrings[status]);
-
-       return CAPTURE_BIN_ERROR;
-   }
-
-   activeChip->setFrameType(frameTypeName);
+   activeChip->setFrameType(frameType);
    activeChip->setCaptureMode(FITS_NORMAL);
 
    if (noCaptureFilter)
@@ -224,10 +230,9 @@ void SequenceJob::setTargetFilter(int pos, const QString & name)
     filter    = name;
 }
 
-void SequenceJob::setFrameType(int type, const QString & name)
+void SequenceJob::setFrameType(CCDFrameType type)
 {
     frameType = type;
-    frameTypeName = name;
 }
 
 double SequenceJob::getExposeLeft() const
@@ -240,22 +245,22 @@ void SequenceJob::setExposeLeft(double value)
     exposeLeft = value;
 }
 
-void SequenceJob::setPrefixSettings(const QString &prefix, bool filterEnabled, bool exposureEnabled, bool tsEnabled)
+void SequenceJob::setPrefixSettings(const QString &rawFilePrefix, bool filterEnabled, bool exposureEnabled, bool tsEnabled)
 {
-    rawPrefix               = prefix;
+    rawPrefix               = rawFilePrefix;
     filterPrefixEnabled     = filterEnabled;
     expPrefixEnabled        = exposureEnabled;
-    timeStampPrefixEnabled        = tsEnabled;
+    timeStampPrefixEnabled  = tsEnabled;
 }
 
-void SequenceJob::getPrefixSettings(QString &prefix, bool &filterEnabled, bool &exposureEnabled, bool &tsEnabled)
+void SequenceJob::getPrefixSettings(QString &rawFilePrefix, bool &filterEnabled, bool &exposureEnabled, bool &tsEnabled)
 {
-    prefix          = rawPrefix;
-
+    rawFilePrefix   = rawPrefix;
     filterEnabled   = filterPrefixEnabled;
     exposureEnabled = expPrefixEnabled;
     tsEnabled       = timeStampPrefixEnabled;
 }
+
 double SequenceJob::getCurrentTemperature() const
 {
     return currentTemperature;
@@ -294,6 +299,17 @@ void SequenceJob::setTargetADU(double value)
 {
     calibrationSettings.targetADU = value;
 }
+
+double SequenceJob::getTargetADUTolerance() const
+{
+    return calibrationSettings.targetADUTolerance;
+}
+
+void SequenceJob::setTargetADUTolerance(double value)
+{
+    calibrationSettings.targetADUTolerance = value;
+}
+
 int SequenceJob::getCaptureRetires() const
 {
     return captureRetires;
@@ -420,6 +436,16 @@ void SequenceJob::setRemoteDir(const QString &value)
     remoteDir = value;
 }
 
+ISD::CCD::TransferFormat SequenceJob::getTransforFormat() const
+{
+    return transforFormat;
+}
+
+void SequenceJob::setTransforFormat(const ISD::CCD::TransferFormat &value)
+{
+    transforFormat = value;
+}
+
 int SequenceJob::getISOIndex() const
 {
     return isoIndex;
