@@ -63,8 +63,8 @@ class QProgressDialog;
 
 typedef struct
 {
-    double ra;
-    double dec;
+    float ra;
+    float dec;
 } wcs_point;
 
 class Edge
@@ -112,7 +112,9 @@ public:
     /* Rescale image lineary from image_buffer, fit to window if desired */
     int rescale(FITSZoom type);
     /* Calculate stats */
-    void calculateStats(bool refresh=false);    
+    void calculateStats(bool refresh=false);
+
+    bool contains(const QPointF& point) const;
 
     // Access functions
     void clearImageBuffers();
@@ -173,10 +175,39 @@ public:
     FITSMode getMode() { return mode;}
 
     // WCS
-    bool checkWCS();
+    bool loadWCS();
     bool hasWCS() { return HasWCS; }
     wcs_point *getWCSCoord()  { return wcs_coord; }
 
+    /**
+     * @brief wcsToPixel Given J2000 (RA0,DE0) coordinates. Find in the image the corresponding pixel coordinates.
+     * @param wcsCoord Coordinates of target
+     * @param wcsPixelPoint Return XY FITS coordinates
+     * @param wcsImagePoint Return XY Image coordinates
+     * @return True if conversion is successfull, false otherwise.
+     */
+    bool wcsToPixel(SkyPoint &wcsCoord, QPointF &wcsPixelPoint, QPointF &wcsImagePoint);
+
+    /**
+     * @brief pixelToWCS Convert Pixel coordinates to J2000 world coordinates
+     * @param wcsPixelPoint Pixel coordinates in XY Image space.
+     * @param wcsCoord Store back WCS world coordinate in wcsCoord
+     * @return True if successful, false otherwise.
+     */
+    bool pixelToWCS(const QPointF &wcsPixelPoint, SkyPoint & wcsCoord);
+
+    /**
+     * @brief createWCSFile Create a new FITS file given the WCS information supplied. Construct the necessary WCS keywords and save the
+     * new file as the current active file
+     * @param newWCSFile New file name
+     * @param orientation Solver orientation, degrees E of N.
+     * @param ra J2000 Right Ascension
+     * @param dec J2000 Declination
+     * @param pixscale Pixel scale in arcsecs per pixel
+     * @return  True if file is successfully created and saved, false otherwise.
+     */
+    bool createWCSFile(const QString & newWCSFile, double orientation, double ra, double dec, double pixscale);
+
     // Debayer
     bool hasDebayer() { return HasDebayer; }
     bool debayer();
@@ -215,7 +246,7 @@ public:
 
     #ifndef KSTARS_LITE
     #ifdef HAVE_WCSLIB
-    void findObjectsInImage(struct wcsprm *wcs, double world[], double phi, double theta, double imgcrd[], double pixcrd[], int stat[]);
+    void findObjectsInImage(double world[], double phi, double theta, double imgcrd[], double pixcrd[], int stat[]);
     #endif
     #endif
     QList<FITSSkyObject *> getSkyObjects();
@@ -224,6 +255,11 @@ public:
     // Create autostretch image from FITS File
     static QImage FITSToImage(const QString &filename);
 
+    bool getAutoRemoveTemporaryFITS() const;
+    void setAutoRemoveTemporaryFITS(bool value);
+
+    QString getLastError() const;
+
 private:
 
     void rotWCSFITS (int angle, int mirror);
@@ -287,6 +323,7 @@ private:
     int flipVCounter;                   // How many times the image was flipped vertically?
 
     wcs_point *wcs_coord;               // Pointer to WCS coordinate data, if any.
+    struct wcsprm *wcs=0;               // WCS Struct
     QList<Edge*> starCenters;           // All the stars we detected, if any.
     Edge* maxHFRStar;                   // The biggest fattest star in the image.
 
@@ -308,6 +345,11 @@ private:
         uint16_t width;
         uint16_t height;
     } stats;
+
+    // Remove temproray files after closing
+    bool autoRemoveTemporaryFITS=true;
+
+    QString lastError;
 };
 
 #endif
