@@ -162,5 +162,14 @@ void DriverInfo::addAuxInfo(const QString & key, const QVariant & value)
     auxInfo[key] = value;
 }
 
+void DriverInfo::setUniqueLabel(const QString &inUniqueLabel)
+{
+    // N.B. We NEVER set unique label for multiple devices per driver "driver"
+    if (auxInfo.value("mdpd", false).toBool() == true || driverSource >= HOST_SOURCE)
+        return;
+
+    uniqueLabel = inUniqueLabel;
+}
+
 
 
