@@ -44,7 +44,7 @@
 
 
 const int MAX_FILENAME_LEN = 1024;
-const QStringList RAWFormats = { "cr2", "crw", "nef", "raf", "dng" };
+const QStringList RAWFormats = { "cr2", "crw", "nef", "raf", "dng", "arw" };
 
 namespace ISD
 {
@@ -123,9 +123,7 @@ void CCDChip::setImageView(FITSView *image, FITSMode imageType)
         break;
 
     case FITS_ALIGN:
-        alignImage = image;
-        if (KStars::Instance()->ekosManager()->alignModule() && KStars::Instance()->ekosManager()->alignModule()->fov())
-            KStars::Instance()->ekosManager()->alignModule()->fov()->setImage(alignImage->getDisplayImage()->copy());
+        alignImage = image;        
         break;
 
     default:
@@ -189,6 +187,68 @@ bool CCDChip::getFrameMinMax(int *minX, int *maxX, int *minY, int *maxY, int *mi
 
 }
 
+bool CCDChip::setImageInfo(uint16_t width, uint16_t height, double pixelX, double pixelY, uint8_t bitdepth)
+{
+    INumberVectorProperty *ccdInfoProp = NULL;
+
+    switch (type)
+    {
+    case PRIMARY_CCD:
+        ccdInfoProp = baseDevice->getNumber("CCD_INFO");
+        break;
+
+    case GUIDE_CCD:
+        ccdInfoProp = baseDevice->getNumber("GUIDER_INFO");
+        break;
+
+    }
+
+    if (ccdInfoProp == NULL)
+        return false;
+
+    ccdInfoProp->np[0].value = width;
+    ccdInfoProp->np[1].value = height;
+    ccdInfoProp->np[2].value = std::hypotf(pixelX, pixelY);
+    ccdInfoProp->np[3].value = pixelX;
+    ccdInfoProp->np[4].value = pixelY;
+    ccdInfoProp->np[5].value = bitdepth;
+
+    clientManager->sendNewNumber(ccdInfoProp);
+
+    return true;
+}
+
+bool CCDChip::getPixelSize(double & x, double & y)
+{
+    INumberVectorProperty *ccdInfoProp = NULL;
+
+    switch (type)
+    {
+    case PRIMARY_CCD:
+        ccdInfoProp = baseDevice->getNumber("CCD_INFO");
+        break;
+
+    case GUIDE_CCD:
+        ccdInfoProp = baseDevice->getNumber("GUIDER_INFO");
+        break;
+
+    }
+
+    if (ccdInfoProp == NULL)
+        return false;
+
+    INumber *pixelX = IUFindNumber(ccdInfoProp, "CCD_PIXEL_SIZE_X");
+    INumber *pixelY = IUFindNumber(ccdInfoProp, "CCD_PIXEL_SIZE_Y");
+
+    if (pixelX == NULL || pixelY == NULL)
+        return false;
+
+    x = pixelX->value;
+    y = pixelY->value;
+
+    return true;
+}
+
 bool CCDChip::getFrame(int *x, int *y, int *w, int *h)
 {
 
@@ -786,6 +846,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
     HasGuideHead = false;
     HasCooler    = false;
     HasCoolerControl = false;
+    HasVideoStream = false;
     fv          = NULL;
     streamWindow      = NULL;
     ST4Driver = NULL;
@@ -796,6 +857,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
     normalTabID = calibrationTabID = focusTabID = guideTabID = alignTabID = -1;
     guideChip   = NULL;
 
+    transferFormat = targetTransferFormat = FORMAT_FITS;
 }
 
 CCD::~CCD()
@@ -872,6 +934,35 @@ void CCD::registerProperty(INDI::Property *prop)
         // Can turn cooling on/off
         HasCoolerControl = true;
     }
+    else if (!strcmp(prop->getName(), "CCD_VIDEO_STREAM"))
+    {
+        // Has Video Stream
+        HasVideoStream = true;
+    }
+    else if (!strcmp(prop->getName(), "CCD_TRANSFER_FORMAT"))
+    {
+        ISwitchVectorProperty *sp = prop->getSwitch();
+        if (sp)
+        {
+            ISwitch *format = IUFindSwitch(sp, "FORMAT_NATIVE");
+            if (format && format->s == ISS_ON)
+                transferFormat = FORMAT_NATIVE;
+            else
+                transferFormat = FORMAT_FITS;
+        }
+    }
+    else if (!strcmp(prop->getName(), "TELESCOPE_TYPE"))
+    {
+        ISwitchVectorProperty *sp = prop->getSwitch();
+        if (sp)
+        {
+            ISwitch *format = IUFindSwitch(sp, "TELESCOPE_PRIMARY");
+            if (format && format->s == ISS_ON)
+                telescopeType = TELESCOPE_PRIMARY;
+            else
+                telescopeType = TELESCOPE_GUIDE;
+        }
+    }
 
     DeviceDecorator::registerProperty(prop);
 }
@@ -888,29 +979,25 @@ void CCD::processNumber(INumberVectorProperty *nvp)
         INumber *np = IUFindNumber(nvp, "CCD_EXPOSURE_VALUE");
         if (np)
             emit newExposureValue(primaryChip, np->value, nvp->s);
-
-        return;
     }
-
-    if (!strcmp(nvp->name, "CCD_TEMPERATURE"))
+    else if (!strcmp(nvp->name, "CCD_TEMPERATURE"))
     {
         HasCooler = true;
         INumber *np = IUFindNumber(nvp, "CCD_TEMPERATURE_VALUE");
         if (np)
             emit newTemperatureValue(np->value);
-
-        return;
     }
-
-    if (!strcmp(nvp->name, "GUIDER_EXPOSURE"))
+    else if (!strcmp(nvp->name, "GUIDER_EXPOSURE"))
     {
         INumber *np = IUFindNumber(nvp, "GUIDER_EXPOSURE_VALUE");
         if (np)
             emit newExposureValue(guideChip, np->value, nvp->s);
-        return;
     }
-
-    if (!strcmp(nvp->name, "CCD_RAPID_GUIDE_DATA"))
+    else if (!strcmp(nvp->name, "FPS"))
+    {
+        emit newFPS(nvp->np[0].value, nvp->np[1].value);
+    }
+    else if (!strcmp(nvp->name, "CCD_RAPID_GUIDE_DATA"))
     {
         double dx=-1,dy=-1,fit=-1;
         INumber *np=NULL;
@@ -934,12 +1021,8 @@ void CCD::processNumber(INumberVectorProperty *nvp)
             if (dx >= 0 && dy >= 0 && fit >= 0)
                 emit newGuideStarData(primaryChip, dx, dy, fit);
         }
-
-        return;
-
     }
-
-    if (!strcmp(nvp->name, "GUIDER_RAPID_GUIDE_DATA"))
+    else if (!strcmp(nvp->name, "GUIDER_RAPID_GUIDE_DATA"))
     {
         double dx=-1,dy=-1,fit=-1;
         INumber *np=NULL;
@@ -964,9 +1047,6 @@ void CCD::processNumber(INumberVectorProperty *nvp)
             if (dx >= 0 && dy >= 0 && fit >= 0)
                 emit newGuideStarData(guideChip, dx, dy, fit);
         }
-
-        return;
-
     }
 
     DeviceDecorator::processNumber(nvp);
@@ -979,63 +1059,104 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
         // Can turn cooling on/off
         HasCoolerControl = true;
     }
-
-    if (!strcmp(svp->name, "CCD_VIDEO_STREAM") || !strcmp(svp->name, "VIDEO_STREAM"))
+    else if (QString(svp->name).endsWith("VIDEO_STREAM"))
     {
+        HasVideoStream = true;
+
         if (streamWindow == NULL && svp->sp[0].s == ISS_ON)
         {
-            streamWindow = new StreamWG();
+            streamWindow = new StreamWG(this);
 
-            // Only use CCD dimensions if we are receing raw stream and not stream of images (i.e. mjpeg..etc)
-            IBLOBVectorProperty *rawBP = baseDevice->getBLOB("CCD1");
-            if (rawBP)
+            INumberVectorProperty *streamFrame = baseDevice->getNumber("CCD_STREAM_FRAME");
+            INumber *w=NULL, *h=NULL;
+            if (streamFrame)
             {
-                int x,y,w,h;
-                int binx, biny;
-
-                primaryChip->getFrame(&x, &y, &w, &h);
-                primaryChip->getBinning(&binx, &biny);
-                streamW = w / binx;
-                streamH = h / biny;
-
-                rawBP->bp[0].aux0 = &(streamW);
-                rawBP->bp[0].aux1 = &(streamH);
-
-                if (streamWindow->getWidth() != streamW || streamWindow->getHeight() != streamH)
-                    streamWindow->setSize(streamW, streamH);
+                w = IUFindNumber(streamFrame, "WIDTH");
+                h = IUFindNumber(streamFrame, "HEIGHT");
             }
 
+            if (w && h)
+            {
+                streamW = w->value;
+                streamH = h->value;
+            }
+            else
+            {
+                // Only use CCD dimensions if we are receing raw stream and not stream of images (i.e. mjpeg..etc)
+                IBLOBVectorProperty *rawBP = baseDevice->getBLOB("CCD1");
+                if (rawBP)
+                {
+                    int x,y,w,h;
+                    int binx, biny;
+
+                    primaryChip->getFrame(&x, &y, &w, &h);
+                    primaryChip->getBinning(&binx, &biny);
+                    streamW = w / binx;
+                    streamH = h / biny;
+                }
+            }
+
+            streamWindow->setSize(streamW, streamH);
         }
 
         if (streamWindow)
         {
             connect(streamWindow, SIGNAL(hidden()), this, SLOT(StreamWindowHidden()), Qt::UniqueConnection);
 
-            if (svp->sp[0].s == ISS_ON)
-                streamWindow->enableStream(true);
-            else
-                streamWindow->enableStream(false);
+            streamWindow->enableStream(svp->sp[0].s == ISS_ON);
+            emit videoStreamToggled(svp->sp[0].s == ISS_ON);
+        }
+    }
+    else if (!strcmp(svp->name, "CCD_TRANSFER_FORMAT"))
+    {
+        ISwitch *format = IUFindSwitch(svp, "FORMAT_NATIVE");
+
+        if (format && format->s == ISS_ON)
+            transferFormat = FORMAT_NATIVE;
+        else
+            transferFormat = FORMAT_FITS;
+
+    }
+    else if (!strcmp(svp->name, "RECORD_STREAM"))
+    {
+        ISwitch *recordOFF = IUFindSwitch(svp, "RECORD_OFF");
+
+        if (recordOFF && recordOFF->s == ISS_ON)
+        {
+            emit videoRecordToggled(false);
+            KNotification::event( QLatin1String( "RecordingStopped" ) , i18n("Video Recording Stopped"));
+        }
+        else
+        {
+            emit videoRecordToggled(true);
+            KNotification::event( QLatin1String( "RecordingStarted" ) , i18n("Video Recording Started"));
         }
 
-
-        emit switchUpdated(svp);
-
-        return;
     }
+    else if (!strcmp(svp->name, "TELESCOPE_TYPE"))
+    {
+        ISwitch *format = IUFindSwitch(svp, "TELESCOPE_PRIMARY");
+        if (format && format->s == ISS_ON)
+            telescopeType = TELESCOPE_PRIMARY;
+        else
+            telescopeType = TELESCOPE_GUIDE;
 
-    if (!strcmp(svp->name, "CONNECTION"))
+    }
+    else if (!strcmp(svp->name, "CONNECTION"))
     {
         ISwitch *dSwitch = IUFindSwitch(svp, "DISCONNECT");
 
         if (dSwitch && dSwitch->s == ISS_ON && streamWindow != NULL)
         {
             streamWindow->enableStream(false);
+            emit videoStreamToggled(false);
             streamWindow->close();
             delete(streamWindow);
             streamWindow = NULL;
         }
 
-        emit switchUpdated(svp);
+        //emit switchUpdated(svp);
+        //return;
 
     }
 
@@ -1050,8 +1171,6 @@ void CCD::processText(ITextVectorProperty *tvp)
         IText *filepath = IUFindText(tvp, "FILE_PATH");
         if (filepath)
             emit newRemoteFile(QString(filepath->text));
-
-        return;
     }
 
     DeviceDecorator::processText(tvp);
@@ -1059,6 +1178,10 @@ void CCD::processText(ITextVectorProperty *tvp)
 
 void CCD::processBLOB(IBLOB* bp)
 {
+    // Ignore write-only BLOBs since we only receive it for state-change
+    if (bp->bvp->p == IP_WO)
+        return;
+
     BType = BLOB_OTHER;
 
     QString format(bp->format);
@@ -1069,16 +1192,40 @@ void CCD::processBLOB(IBLOB* bp)
         if (streamWindow->isStreamEnabled() == false)
             return;
 
-        int x,y,w,h;
-        int binx, biny;
+        INumberVectorProperty *streamFrame = baseDevice->getNumber("CCD_STREAM_FRAME");
+        INumber *w=NULL, *h=NULL;
+        if (streamFrame)
+        {
+            w = IUFindNumber(streamFrame, "WIDTH");
+            h = IUFindNumber(streamFrame, "HEIGHT");
+        }
 
-        primaryChip->getFrame(&x, &y, &w, &h);
-        primaryChip->getBinning(&binx, &biny);
-        streamW = w / binx;
-        streamH = h / biny;
+        if (w && h)
+        {
+            streamW = w->value;
+            streamH = h->value;
+        }
+        else
+        {
+            int x,y,w,h;
+            int binx, biny;
 
-        if (streamWindow->getWidth() != streamW || streamWindow->getHeight() != streamH)
-            streamWindow->setSize(streamW, streamH);
+            primaryChip->getFrame(&x, &y, &w, &h);
+            primaryChip->getBinning(&binx, &biny);
+            streamW = w / binx;
+            streamH = h / biny;
+
+            /*IBLOBVectorProperty *rawBP = baseDevice->getBLOB("CCD1");
+            if (rawBP)
+            {
+                rawBP->bp[0].aux0 = &(streamW);
+                rawBP->bp[0].aux1 = &(streamH);
+            }*/
+        }
+
+        //if (streamWindow->getStreamWidth() != streamW || streamWindow->getStreamHeight() != streamH)
+
+        streamWindow->setSize(streamW, streamH);
 
         streamWindow->show();
         streamWindow->newFrame(bp);
@@ -1157,7 +1304,9 @@ void CCD::processBLOB(IBLOB* bp)
     // Create file name for others
     else
     {
-        QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
+        // IS8601 contains colons but they are illegal under Windows OS, so replacing them with '-'
+        // The timestamp is no longer ISO8601 but it should solve interoperality issues between different OS hosts
+        QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh-mm-ss");
 
         if (ISOMode == false)
             filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") +  QString("%1.%2").arg(QString().sprintf("%03d", nextSequenceID)).arg(QString(fmt));
@@ -1288,17 +1437,26 @@ void CCD::processBLOB(IBLOB* bp)
     {
         QUrl fileURL = QUrl::fromLocalFile(filename);
 
-        if (fv.isNull())
-        {
-            normalTabID = calibrationTabID = focusTabID = guideTabID = alignTabID = -1;
+        // If there is no FITSViewer, create it. Unless it is a dedicated Focus or Guide frame
+        // then no need for a FITS Viewer as they get displayed inside Ekos
+        if (Options::useFITSViewerInCapture()||!targetChip->isBatchMode()){
+            if (fv.isNull() && targetChip->getCaptureMode() != FITS_GUIDE
+                            && targetChip->getCaptureMode() != FITS_FOCUS
+                            && targetChip->getCaptureMode() != FITS_ALIGN)
+            {
+                normalTabID = calibrationTabID = focusTabID = guideTabID = alignTabID = -1;
 
-            if (Options::singleWindowCapturedFITS())
-                fv = KStars::Instance()->genericFITSViewer();
-            else
-                fv = new FITSViewer(Options::independentWindowFITS() ? NULL : KStars::Instance());
+                if (Options::singleWindowCapturedFITS())
+                    fv = KStars::Instance()->genericFITSViewer();
+                else
+                {
+                    fv = new FITSViewer(Options::independentWindowFITS() ? NULL : KStars::Instance());
+                    KStars::Instance()->getFITSViewersList().append(fv);
+                }
 
-            //connect(fv, SIGNAL(destroyed()), this, SLOT(FITSViewerDestroyed()));
-            //connect(fv, SIGNAL(destroyed()), this, SIGNAL(FITSViewerClosed()));
+                //connect(fv, SIGNAL(destroyed()), this, SLOT(FITSViewerDestroyed()));
+                //connect(fv, SIGNAL(destroyed()), this, SIGNAL(FITSViewerClosed()));
+            }
         }
 
         FITSScale captureFilter = targetChip->getCaptureFilter();
@@ -1320,28 +1478,44 @@ void CCD::processBLOB(IBLOB* bp)
         {
         case FITS_NORMAL:
         {
-            if (normalTabID == -1 || Options::singlePreviewFITS() == false)
-                tabRC = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
-            else if (fv->updateFITS(&fileURL, normalTabID, captureFilter) == false)
+            //This is how to get the image to show up in the EkosManger preview FitsView.
+            FITSView *previewView = KStars::Instance()->ekosManager()->getPreviewView();
+            if (previewView)
             {
-                fv->removeFITS(normalTabID);
-                tabRC = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
+                previewView->setFilter(captureFilter);
+                bool imageLoad = previewView->loadFITS(filename, true);
+                if (imageLoad)
+                    previewView->updateFrame();
             }
-            else
-                tabRC = normalTabID;
+            if (Options::useFITSViewerInCapture()||!targetChip->isBatchMode()){
+                if (normalTabID == -1 || Options::singlePreviewFITS() == false)
+                    tabRC = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
+                else if (fv->updateFITS(&fileURL, normalTabID, captureFilter) == false)
+                {
+                    fv->removeFITS(normalTabID);
+                    tabRC = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
+                }
+                else
+                    tabRC = normalTabID;
 
-            if (tabRC >= 0)
-            {
-                normalTabID = tabRC;
-                targetChip->setImageView(fv->getView(normalTabID), FITS_NORMAL);
+                if (tabRC >= 0)
+                {
+                    normalTabID = tabRC;
+                    targetChip->setImageView(fv->getView(normalTabID), FITS_NORMAL);
 
-                emit newImage(fv->getView(normalTabID)->getDisplayImage(), targetChip);
-            }
-            else
-            {
-                // If opening file fails, we treat it the same as exposure failure and recapture again if possible
-                emit newExposureValue(targetChip, 0, IPS_ALERT);
-                return;
+                    emit newImage(fv->getView(normalTabID)->getDisplayImage(), targetChip);
+                }
+                else
+                {
+                    // If opening file fails, we treat it the same as exposure failure and recapture again if possible
+                    emit newExposureValue(targetChip, 0, IPS_ALERT);
+                    return;
+                }
+            } else{
+                if(previewView){
+                    targetChip->setImageView(previewView,FITS_NORMAL);
+                    emit newImage(previewView->getDisplayImage(), targetChip);
+                }
             }
         }
             break;
@@ -1440,29 +1614,32 @@ void CCD::processBLOB(IBLOB* bp)
             break;
 
         case FITS_CALIBRATE:
-            if (calibrationTabID == -1)
-                tabRC = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
-            else if (fv->updateFITS(&fileURL, calibrationTabID, captureFilter) == false)
-            {
-                fv->removeFITS(calibrationTabID);
-                tabRC = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
-            }
-            else
-                tabRC = calibrationTabID;
+            if (Options::useFITSViewerInCapture()||!targetChip->isBatchMode()){
+                if (calibrationTabID == -1)
+                    tabRC = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
+                else if (fv->updateFITS(&fileURL, calibrationTabID, captureFilter) == false)
+                {
+                    fv->removeFITS(calibrationTabID);
+                    tabRC = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
+                }
+                else
+                    tabRC = calibrationTabID;
 
-            if (tabRC >= 0)
-            {
-                calibrationTabID = tabRC;
-                targetChip->setImageView(fv->getView(calibrationTabID), FITS_CALIBRATE);
-            }
-            else
-            {
-                emit newExposureValue(targetChip, 0, IPS_ALERT);
-                return;
-            }
+                if (tabRC >= 0)
+                {
+                    calibrationTabID = tabRC;
+                    targetChip->setImageView(fv->getView(calibrationTabID), FITS_CALIBRATE);
+                }
+                else
+                {
+                    emit newExposureValue(targetChip, 0, IPS_ALERT);
+                    return;
+                }
+          }
             break;
 
         case FITS_ALIGN:
+            /*
             if (alignTabID == -1)
                 tabRC = fv->addFITS(&fileURL, FITS_ALIGN, captureFilter);
             else if (fv->updateFITS(&fileURL, alignTabID, captureFilter) == false)
@@ -1482,17 +1659,38 @@ void CCD::processBLOB(IBLOB* bp)
             {
                 emit newExposureValue(targetChip, 0, IPS_ALERT);
                 return;
-            }
-            break;
+            }*/
 
+        {
+            FITSView *alignView = targetChip->getImageView(FITS_ALIGN);
+            if (alignView)
+            {
+                alignView->setFilter(captureFilter);
+                bool imageLoad = alignView->loadFITS(filename, true);
+                if (imageLoad)
+                {
+                    //alignView->rescale(ZOOM_FIT_WINDOW);
+                    alignView->updateFrame();
+                    emit newImage(alignView->getDisplayImage(), targetChip);
+                }
+                else
+                {
+                    emit newExposureValue(targetChip, 0, IPS_ALERT);
+                    return;
+                }
+            }
+        }
+        break;
 
         default:
             break;
 
         }
 
-        if (targetChip->getCaptureMode() != FITS_GUIDE && targetChip->getCaptureMode() != FITS_FOCUS)
-            fv->show();
+        if (Options::useFITSViewerInCapture()||!targetChip->isBatchMode()){
+            if (targetChip->getCaptureMode() == FITS_NORMAL || targetChip->getCaptureMode() == FITS_CALIBRATE)
+                fv->show();
+        }
     }
 #endif
 
@@ -1531,6 +1729,16 @@ void CCD::addFITSKeywords(QString filename)
 #endif
 }
 
+CCD::TransferFormat CCD::getTargetTransferFormat() const
+{
+    return targetTransferFormat;
+}
+
+void CCD::setTargetTransferFormat(const TransferFormat &value)
+{
+    targetTransferFormat = value;
+}
+
 void CCD::FITSViewerDestroyed()
 {
     fv = NULL;
@@ -1541,19 +1749,40 @@ void CCD::StreamWindowHidden()
 {
     if (baseDevice->isConnected())
     {
+        // We can have more than one *_VIDEO_STREAM property active so disable them all
         ISwitchVectorProperty *streamSP = baseDevice->getSwitch("CCD_VIDEO_STREAM");
-        if (streamSP == NULL)
-            streamSP = baseDevice->getSwitch("VIDEO_STREAM");
         if (streamSP)
         {
             IUResetSwitch(streamSP);
+            streamSP->sp[0].s = ISS_OFF;
+            streamSP->sp[1].s = ISS_ON;
+            streamSP->s = IPS_IDLE;
+            clientManager->sendNewSwitch(streamSP);
+        }
+
+        streamSP = baseDevice->getSwitch("VIDEO_STREAM");
+        if (streamSP)
+        {
+            IUResetSwitch(streamSP);
+            streamSP->sp[0].s = ISS_OFF;
+            streamSP->sp[1].s = ISS_ON;
+            streamSP->s = IPS_IDLE;
+            clientManager->sendNewSwitch(streamSP);
+        }
+
+        streamSP = baseDevice->getSwitch("AUX_VIDEO_STREAM");
+        if (streamSP)
+        {
+            IUResetSwitch(streamSP);
+            streamSP->sp[0].s = ISS_OFF;
             streamSP->sp[1].s = ISS_ON;
             streamSP->s = IPS_IDLE;
             clientManager->sendNewSwitch(streamSP);
         }
     }
 
-    streamWindow->disconnect();
+    if (streamWindow)
+            streamWindow->disconnect();
 }
 
 bool CCD::hasGuideHead()
@@ -1807,4 +2036,290 @@ bool CCD::setTemperature(double value)
     return true;
 }
 
+bool CCD::setTransformFormat(CCD::TransferFormat format)
+{
+    if (format == transferFormat)
+        return true;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("CCD_TRANSFER_FORMAT");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *formatFITS   = IUFindSwitch(svp, "FORMAT_FITS");
+    ISwitch *formatNative = IUFindSwitch(svp, "FORMAT_NATIVE");
+
+    if (formatFITS  == NULL || formatNative == NULL)
+        return false;
+
+    transferFormat = format;
+
+    formatFITS->s   = (transferFormat == FORMAT_FITS) ? ISS_ON : ISS_OFF;
+    formatNative->s = (transferFormat == FORMAT_FITS) ? ISS_OFF : ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::setTelescopeType(TelescopeType type)
+{
+    if (type == telescopeType)
+        return true;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("TELESCOPE_TYPE");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *typePrimary   = IUFindSwitch(svp, "TELESCOPE_PRIMARY");
+    ISwitch *typeGuide     = IUFindSwitch(svp, "TELESCOPE_GUIDE");
+
+    if (typePrimary  == NULL || typeGuide == NULL)
+        return false;
+
+    telescopeType = type;
+
+    typePrimary->s   = (telescopeType == TELESCOPE_PRIMARY) ? ISS_ON : ISS_OFF;
+    typeGuide->s     = (telescopeType == TELESCOPE_PRIMARY) ? ISS_OFF : ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    setConfig(SAVE_CONFIG);
+
+    return true;
+}
+
+bool CCD::setVideoStreamEnabled(bool enable)
+{
+    if (HasVideoStream == false)
+        return false;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("CCD_VIDEO_STREAM");
+    if (svp == NULL)
+        return false;
+
+    // If already on and enable is set or vice versa no need to change anything we return true
+    if ( (enable && svp->sp[0].s == ISS_ON) || (!enable && svp->sp[1].s == ISS_ON))
+         return true;
+
+    svp->sp[0].s = enable ? ISS_ON : ISS_OFF;
+    svp->sp[1].s = enable ? ISS_OFF : ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::resetStreamingFrame()
+{
+    INumberVectorProperty *frameProp = baseDevice->getNumber("CCD_STREAM_FRAME");
+
+    if (frameProp == NULL)
+        return false;
+
+    INumber *xarg = IUFindNumber(frameProp, "X");
+    INumber *yarg = IUFindNumber(frameProp, "Y");
+    INumber *warg = IUFindNumber(frameProp, "WIDTH");
+    INumber *harg = IUFindNumber(frameProp, "HEIGHT");
+
+    if (xarg && yarg && warg && harg)
+    {
+        if (xarg->value == xarg->min && yarg->value == yarg->min && warg->value == warg->max && harg->value == harg->max)
+            return false;
+
+        xarg->value = xarg->min;
+        yarg->value = yarg->min;
+        warg->value = warg->max;
+        harg->value = harg->max;
+
+        clientManager->sendNewNumber(frameProp);
+        return true;
+    }
+
+    return false;
+}
+
+bool CCD::setStreamingFrame(int x, int y, int w, int h)
+{
+    INumberVectorProperty *frameProp = baseDevice->getNumber("CCD_STREAM_FRAME");
+
+    if (frameProp == NULL)
+        return false;
+
+    INumber *xarg = IUFindNumber(frameProp, "X");
+    INumber *yarg = IUFindNumber(frameProp, "Y");
+    INumber *warg = IUFindNumber(frameProp, "WIDTH");
+    INumber *harg = IUFindNumber(frameProp, "HEIGHT");
+
+    if (xarg && yarg && warg && harg)
+    {
+        if (xarg->value == x && yarg->value == y && warg->value == w && harg->value == h)
+            return true;
+
+        // N.B. We add offset since the X, Y are relative to whatever streaming frame is currently active
+        xarg->value = qBound(xarg->min, static_cast<double>(x)+xarg->value, xarg->max);
+        yarg->value = qBound(yarg->min, static_cast<double>(y)+yarg->value, yarg->max);
+        warg->value = qBound(warg->min, static_cast<double>(w), warg->max);
+        harg->value = qBound(harg->min, static_cast<double>(h), harg->max);
+
+        clientManager->sendNewNumber(frameProp);
+        return true;
+    }
+
+    return false;
+
+}
+
+bool CCD::isStreamingEnabled()
+{
+    if (HasVideoStream == false || streamWindow == NULL)
+        return false;
+
+    return streamWindow->isStreamEnabled();
+}
+
+bool CCD::setSERNameDirectory(const QString &filename, const QString &directory)
+{
+    ITextVectorProperty *tvp = baseDevice->getText("RECORD_FILE");
+    if (tvp == NULL)
+        return false;
+
+    IText *filenameT = IUFindText(tvp, "RECORD_FILE_NAME");
+    IText *dirT      = IUFindText(tvp, "RECORD_FILE_DIR");
+
+    if (filenameT == NULL || dirT == NULL)
+        return false;
+
+    IUSaveText(filenameT, filename.toLatin1().data());
+    IUSaveText(dirT, directory.toLatin1().data());
+
+    clientManager->sendNewText(tvp);
+
+    return true;
+}
+
+bool CCD::getSERNameDirectory(QString &filename, QString &directory)
+{
+    ITextVectorProperty *tvp = baseDevice->getText("RECORD_FILE");
+    if (tvp == NULL)
+        return false;
+
+    IText *filenameT = IUFindText(tvp, "RECORD_FILE_NAME");
+    IText *dirT      = IUFindText(tvp, "RECORD_FILE_DIR");
+
+    if (filenameT == NULL || dirT == NULL)
+        return false;
+
+    filename = QString(filenameT->text);
+    directory= QString(dirT->text);
+
+    return true;
+}
+
+bool CCD::startRecording()
+{
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("RECORD_STREAM");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *recordON = IUFindSwitch(svp, "RECORD_ON");
+    if (recordON == NULL)
+        return false;
+
+    if (recordON->s == ISS_ON)
+        return true;
+
+    IUResetSwitch(svp);
+    recordON->s = ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::startDurationRecording(double duration)
+{
+    INumberVectorProperty *nvp = baseDevice->getNumber("RECORD_OPTIONS");
+    if (nvp == NULL)
+        return false;
+
+    INumber *durationN = IUFindNumber(nvp, "RECORD_DURATION");
+    if (durationN == NULL)
+        return false;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("RECORD_STREAM");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *recordON = IUFindSwitch(svp, "RECORD_DURATION_ON");
+    if (recordON == NULL)
+        return false;
+
+    if (recordON->s == ISS_ON)
+        return true;
+
+    durationN->value = duration;
+    clientManager->sendNewNumber(nvp);
+
+    IUResetSwitch(svp);
+    recordON->s = ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::startFramesRecording(uint32_t frames)
+{
+    INumberVectorProperty *nvp = baseDevice->getNumber("RECORD_OPTIONS");
+    if (nvp == NULL)
+        return false;
+
+    INumber *frameN = IUFindNumber(nvp, "RECORD_FRAME_TOTAL");
+    if (frameN == NULL)
+        return false;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("RECORD_STREAM");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *recordON = IUFindSwitch(svp, "RECORD_FRAME_ON");
+    if (recordON == NULL)
+        return false;
+
+    if (recordON->s == ISS_ON)
+        return true;
+
+    frameN->value = frames;
+    clientManager->sendNewNumber(nvp);
+
+    IUResetSwitch(svp);
+    recordON->s = ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::stopRecording()
+{
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("RECORD_STREAM");
+    if (svp == NULL)
+        return false;
+
+    ISwitch *recordOFF = IUFindSwitch(svp, "RECORD_OFF");
+    if (recordOFF == NULL)
+        return false;
+
+    // If already set
+    if (recordOFF->s == ISS_ON)
+        return true;
+
+    IUResetSwitch(svp);
+    recordOFF->s = ISS_ON;
+
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
 }
