@@ -7,6 +7,8 @@
     version 2 of the License, or (at your option) any later version.
  */
 
+#include <KNotification>
+
 #include <indi/indidevice.h>
 
 #include "Options.h"
@@ -25,8 +27,14 @@ Telescope::Telescope(GDInterface *iPtr) : DeviceDecorator(iPtr)
 {
     dType = KSTARS_TELESCOPE;
     minAlt=-1;
-    maxAlt=-1;
-    IsParked=false;
+    maxAlt=-1;    
+    EqCoordPreviousState=IPS_IDLE;
+
+    centerLockTimer = new QTimer(this);
+    // Set it for 5 seconds for now as not to spam the display update
+    centerLockTimer->setInterval(5000);
+    centerLockTimer->setSingleShot(true);
+    connect(centerLockTimer, &QTimer::timeout, this, [this]() { runCommand(INDI_CENTER_LOCK); });
 }
 
 Telescope::~Telescope()
@@ -91,7 +99,10 @@ void Telescope::registerProperty(INDI::Property *prop)
              ISwitch *sp = IUFindSwitch(svp, "PARK");
              if (sp)
              {
-                 IsParked = ( (sp->s == ISS_ON) && svp->s == IPS_OK);
+                 if ( (sp->s == ISS_ON) && svp->s == IPS_OK)
+                     parkStatus = PARK_PARKED;
+                 else if ( (sp->s == ISS_OFF) && svp->s == IPS_OK)
+                     parkStatus = PARK_UNPARKED;
              }
          }
     }
@@ -101,7 +112,6 @@ void Telescope::registerProperty(INDI::Property *prop)
 
 void Telescope::processNumber(INumberVectorProperty *nvp)
 {
-
     if (!strcmp(nvp->name, "EQUATORIAL_EOD_COORD"))
     {
         INumber *RA = IUFindNumber(nvp, "RA");
@@ -113,14 +123,26 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
         currentCoord.setDec(DEC->value);
         currentCoord.EquatorialToHorizontal(KStars::Instance()->data()->lst(), KStars::Instance()->data()->geo()->lat());
 
+        if (nvp->s == IPS_BUSY && EqCoordPreviousState != IPS_BUSY)
+        {
+            if (getStatus() != MOUNT_PARKING)
+                   KNotification::event( QLatin1String( "SlewStarted" ) , i18n("Mount is slewing to target location"));
+        }
+        else if (EqCoordPreviousState == IPS_BUSY && nvp->s == IPS_OK)
+        {
+                 KNotification::event( QLatin1String( "SlewCompleted" ) , i18n("Mount arrived at target location"));
+
+                 double maxrad = 1000.0/Options::zoomFactor();
+                 currentObject = KStarsData::Instance()->skyComposite()->objectNearest(&currentCoord, maxrad );
+                 if (currentObject != NULL)
+                     emit newTarget(currentObject->name());
+        }
+
+        EqCoordPreviousState = nvp->s;
+
         KStars::Instance()->map()->update();
-
-        emit numberUpdated(nvp);
-
-        return;
     }
-
-    if (!strcmp(nvp->name, "HORIZONTAL_COORD"))
+    else if (!strcmp(nvp->name, "HORIZONTAL_COORD"))
     {
         INumber *Az = IUFindNumber(nvp, "AZ");
         INumber *Alt = IUFindNumber(nvp, "ALT");
@@ -133,30 +155,60 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
 
         KStars::Instance()->map()->update();
 
-        emit numberUpdated(nvp);
-
-        return;
     }
 
     DeviceDecorator::processNumber(nvp);
-
 }
 
 void Telescope::processSwitch(ISwitchVectorProperty *svp)
 {
-
     if (!strcmp(svp->name, "TELESCOPE_PARK"))
     {
         ISwitch *sp = IUFindSwitch(svp, "PARK");
         if (sp)
         {
-            IsParked = ( (sp->s == ISS_ON) && svp->s == IPS_OK);
+            if (svp->s == IPS_ALERT)
+            {
+                // If alert, set park status to whatever it was opposite to. That is, if it was parking and failed
+                // then we set status to unparked since it did not successfully complete parking.
+                if (parkStatus == PARK_PARKING)
+                    parkStatus = PARK_UNPARKED;
+                else if (parkStatus == PARK_UNPARKING)
+                    parkStatus = PARK_PARKED;
+
+                KNotification::event( QLatin1String( "MountParkingFailed" ) , i18n("Mount parking failed"));
+            }
+            else if (svp->s == IPS_BUSY && sp->s == ISS_ON && parkStatus != PARK_PARKING)
+            {
+                parkStatus = PARK_PARKING;
+                KNotification::event( QLatin1String( "MountParking" ) , i18n("Mount parking is in progress"));
+                currentObject = NULL;
+            }
+            else if (svp->s == IPS_BUSY && sp->s == ISS_OFF && parkStatus != PARK_UNPARKING)
+            {
+                parkStatus = PARK_UNPARKING;
+                KNotification::event( QLatin1String( "MountUnParking" ) , i18n("Mount unparking is in progress"));
+            }
+            else if (svp->s == IPS_OK && sp->s == ISS_ON && parkStatus != PARK_PARKED)
+            {
+                parkStatus = PARK_PARKED;
+                KNotification::event( QLatin1String( "MountParked" ) , i18n("Mount parked"));
+                currentObject = NULL;
+            }
+            else if (svp->s == IPS_OK && sp->s == ISS_OFF && parkStatus != PARK_UNPARKED)
+            {
+                parkStatus = PARK_UNPARKED;
+                KNotification::event( QLatin1String( "MountUnparked" ) , i18n("Mount unparked"));
+                currentObject = NULL;
+            }
+        }
+    }
+    else if (!strcmp(svp->name, "TELESCOPE_ABORT_MOTION"))
+    {
+        if (svp->s == IPS_OK)
+        {
+            KNotification::event( QLatin1String( "MountAborted" ) , i18n("Mount motion was aborted"));
         }
-
-        emit switchUpdated(svp);
-
-        return;
-
     }
 
     DeviceDecorator::processSwitch(svp);
@@ -164,7 +216,6 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
 
 void Telescope::processText(ITextVectorProperty *tvp)
 {
-
     DeviceDecorator::processText(tvp);
 }
 
@@ -331,6 +382,31 @@ bool Telescope::runCommand(int command, void *ptr)
         }
         break;
 
+    case INDI_CENTER_LOCK:
+        {
+            //if (currentObject == NULL || KStars::Instance()->map()->focusObject() != currentObject)
+            if (Options::isTracking() == false || currentCoord.angularDistanceTo(KStars::Instance()->map()->focus()).Degrees() > 0.5)
+            {
+                SkyPoint J2000Coord(currentCoord.ra(), currentCoord.dec());
+                J2000Coord.apparentCoord(KStars::Instance()->data()->ut().djd(), (long double) J2000);
+                currentCoord.setRA0(J2000Coord.ra());
+                currentCoord.setDec0(J2000Coord.dec());
+                //KStars::Instance()->map()->setClickedPoint(&currentCoord);
+                //KStars::Instance()->map()->slotCenter();
+                KStars::Instance()->map()->setDestination(currentCoord);
+                KStars::Instance()->map()->setFocusPoint(&currentCoord);
+                KStars::Instance()->map()->setFocusObject(currentObject);
+                Options::setIsTracking( true );
+            }
+            centerLockTimer->start();
+        }
+        break;
+
+    case INDI_CENTER_UNLOCK:
+        KStars::Instance()->map()->stopTracking();
+        centerLockTimer->stop();
+        break;
+
     default:
         return DeviceDecorator::runCommand(command, ptr);
         break;
@@ -456,9 +532,9 @@ bool Telescope::sendCoords(SkyPoint *ScopeTarget)
         }
 
         double maxrad = 1000.0/Options::zoomFactor();
-        SkyObject *so = KStarsData::Instance()->skyComposite()->objectNearest(ScopeTarget, maxrad );
-        if (so)
-            emit newTarget(so->name());
+        currentObject = KStarsData::Instance()->skyComposite()->objectNearest(ScopeTarget, maxrad );
+        if (currentObject)
+            emit newTarget(currentObject->name());
 
         return true;
 
@@ -709,9 +785,69 @@ void Telescope::setAltLimits(double minAltitude, double maxAltitude)
     maxAlt=maxAltitude;
 }
 
-bool Telescope::isParked()
+bool Telescope::setAlignmentModelEnabled(bool enable)
 {
-    return IsParked;
+    bool wasExecuted=false;
+    ISwitchVectorProperty *alignSwitch = NULL;
+
+    // For INDI Alignment Subsystem
+    alignSwitch = baseDevice->getSwitch("ALIGNMENT_SUBSYSTEM_ACTIVE");
+    if (alignSwitch)
+    {
+        alignSwitch->sp[0].s = enable ? ISS_ON : ISS_OFF;
+        clientManager->sendNewSwitch(alignSwitch);
+        wasExecuted = true;
+    }
+
+    // For EQMod Alignment --- Temporary until all drivers switch fully to INDI Alignment Subsystem
+    alignSwitch = baseDevice->getSwitch("ALIGNMODE");
+    if (alignSwitch)
+    {
+        IUResetSwitch(alignSwitch);
+        // For now, always set alignment mode to NSTAR on enable.
+        if (enable)
+            alignSwitch->sp[2].s = ISS_ON;
+        // Otherwise, set to NO ALIGN
+        else
+            alignSwitch->sp[0].s = ISS_ON;
+
+        clientManager->sendNewSwitch(alignSwitch);
+        wasExecuted = true;
+    }
+
+    return wasExecuted;
+}
+
+bool Telescope::clearAlignmentModel()
+{
+    bool wasExecuted = false;
+
+    // Note: Should probably use INDI Alignment Subsystem Client API in the future?
+    ISwitchVectorProperty *clearSwitch = baseDevice->getSwitch("ALIGNMENT_POINTSET_ACTION");
+    ISwitchVectorProperty *commitSwitch = baseDevice->getSwitch("ALIGNMENT_POINTSET_COMMIT");
+    if (clearSwitch && commitSwitch)
+    {
+        IUResetSwitch(clearSwitch);
+        // ALIGNMENT_POINTSET_ACTION.CLEAR
+        clearSwitch->sp[4].s = ISS_ON;
+        clientManager->sendNewSwitch(clearSwitch);
+        commitSwitch->sp[0].s = ISS_ON;
+        clientManager->sendNewSwitch(commitSwitch);
+        wasExecuted = true;
+    }
+
+    // For EQMod Alignment --- Temporary until all drivers switch fully to INDI Alignment Subsystem
+    clearSwitch = baseDevice->getSwitch("ALIGNLIST");
+    if (clearSwitch)
+    {
+        // ALIGNLISTCLEAR
+        IUResetSwitch(clearSwitch);
+        clearSwitch->sp[1].s = ISS_ON;
+        clientManager->sendNewSwitch(clearSwitch);
+        wasExecuted = true;
+    }
+
+    return wasExecuted;
 }
 
 Telescope::TelescopeStatus Telescope::getStatus()
