@@ -20,6 +20,8 @@
 #include <QStringList>
 #include <QComboBox>
 
+#include "ksnotification.h"
+
 #include "Options.h"
 
 #include "kstars.h"
@@ -32,14 +34,6 @@ OpsINDI::OpsINDI()
     //Get a pointer to the KConfigDialog
     m_ConfigDialog = KConfigDialog::exists( "settings" );
 
-    if (Options::fitsDir().isEmpty())
-    {
-        kcfg_fitsDir->setText (QDir:: homePath());
-        Options::setFitsDir( kcfg_fitsDir->text());
-    }
-    else
-        kcfg_fitsDir->setText ( Options::fitsDir());
-
     selectFITSDirB->setIcon( QIcon::fromTheme( "document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")) );
     selectFITSDirB->setAttribute(Qt::WA_LayoutUsesWidgetRect);
     selectDriversDirB->setIcon( QIcon::fromTheme( "document-open-folder", QIcon(":/icons/breeze/default/document-open-folder.svg")) );
@@ -64,6 +58,7 @@ OpsINDI::OpsINDI()
     connect(selectFITSDirB, SIGNAL(clicked()), this, SLOT(saveFITSDirectory()));
     connect(selectDriversDirB, SIGNAL(clicked()), this, SLOT(saveDriversDirectory()));    
     connect(showLogsB, SIGNAL(clicked()), this, SLOT(slotShowLogFiles()));
+    connect(kcfg_indiServer, SIGNAL(editingFinished()), this, SLOT(verifyINDIServer()));
 
     #ifdef Q_OS_WIN
     kcfg_indiServer->setEnabled(false);
@@ -79,7 +74,7 @@ void OpsINDI::toggleINDIInternal()
     if(kcfg_indiServerIsInternal->isChecked())
         kcfg_indiServer->setText("*Internal INDI Server*");
     else
-        kcfg_indiServer->setText("/usr/local/bin/indiserver");
+        kcfg_indiServer->setText(KSUtils::getDefaultPath("indiServer"));
 }
 
 void OpsINDI::toggleDriversInternal()
@@ -88,7 +83,7 @@ void OpsINDI::toggleDriversInternal()
     if(kcfg_indiDriversAreInternal->isChecked())
         kcfg_indiDriversDir->setText("*Internal INDI Drivers*");
     else
-        kcfg_indiDriversDir->setText("/usr/local/bin/");
+        kcfg_indiDriversDir->setText(KSUtils::getDefaultPath("indiDriversDir"));
 }
 
 void OpsINDI::saveFITSDirectory()
@@ -114,3 +109,17 @@ void OpsINDI::slotShowLogFiles()
     QDesktopServices::openUrl(path);
 }
 
+void OpsINDI::verifyINDIServer()
+{
+    // Do not verify internal
+    if (kcfg_indiServerIsInternal->isChecked())
+        return;
+
+    QFileInfo indiserver(kcfg_indiServer->text());
+
+    if (indiserver.exists() && indiserver.isFile() && indiserver.baseName() == "indiserver")
+        return;
+
+    KSNotification::error(i18n("%1 is not a valid INDI server binary!", kcfg_indiServer->text()));
+}
+
