@@ -28,8 +28,8 @@ EclipticItem::EclipticItem(Ecliptic *eclipticComp, RootNode *rootNode)
 {
     LineListHash *trixels = eclipticComp->lineIndex();
 
-    QHash< Trixel, LineListList *>::const_iterator i = trixels->begin();
-    while( i != trixels->end()) {
+    QHash< Trixel, LineListList *>::const_iterator i = trixels->cbegin();
+    while( i != trixels->cend()) {
         LineListList *linesList = *i;
 
         QList<LineList *> addedLines;
