@@ -102,9 +102,12 @@ OpsColors::OpsColors()
     else
         kcfg_StarColorIntensity->setEnabled( true );
 
+    kcfg_DarkAppColors->setChecked(KStarsData::Instance()->colorScheme()->useDarkPalette());
+
     connect( ColorPalette, SIGNAL( itemClicked( QListWidgetItem* ) ), this, SLOT( newColor( QListWidgetItem* ) ) );
     connect( kcfg_StarColorIntensity, SIGNAL( valueChanged( int ) ), this, SLOT( slotStarColorIntensity( int ) ) );
     connect( kcfg_StarColorMode, SIGNAL( activated( int ) ), this, SLOT( slotStarColorMode( int ) ) );
+    connect( kcfg_DarkAppColors, SIGNAL(toggled(bool)), this, SLOT(slotDarkAppColors(bool)));
     connect( PresetBox, SIGNAL( currentRowChanged( int ) ), this, SLOT( slotPreset( int ) ) );
     connect( AddPreset, SIGNAL( clicked() ), this, SLOT( slotAddPreset() ) );
     connect( RemovePreset, SIGNAL( clicked() ), this, SLOT( slotRemovePreset() ) );
@@ -138,9 +141,8 @@ void OpsColors::newColor( QListWidgetItem *item ) {
 
     #ifdef HAVE_CFITSIO
     QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
-    foreach(FITSViewer *viewer, viewers){
+    foreach(FITSViewer *viewer, viewers)
         viewer->getCurrentView()->updateFrame();
-    }
     #endif
 }
 
@@ -166,6 +168,7 @@ bool OpsColors::setColors( const QString &filename ) {
 
     kcfg_StarColorMode->setCurrentIndex( KStarsData::Instance()->colorScheme()->starColorMode() );
     kcfg_StarColorIntensity->setValue( KStarsData::Instance()->colorScheme()->starColorIntensity() );
+    kcfg_DarkAppColors->setChecked(KStarsData::Instance()->colorScheme()->useDarkPalette());
 
     for ( unsigned int i=0; i < KStarsData::Instance()->colorScheme()->numberOfColors(); ++i ) {
         QColor itemColor( KStarsData::Instance()->colorScheme()->colorAt( i ) );
@@ -175,12 +178,12 @@ bool OpsColors::setColors( const QString &filename ) {
     }
 
     KStars::Instance()->map()->forceUpdate();
-#ifdef HAVE_CFITSIO
+    #ifdef HAVE_CFITSIO
     QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
-    foreach(FITSViewer *viewer, viewers){
+    foreach(FITSViewer *viewer, viewers)
         viewer->getCurrentView()->updateFrame();
-    }
-#endif
+    #endif
+
     return true;
 }
 
@@ -275,4 +278,10 @@ void OpsColors::slotStarColorIntensity( int i ) {
     KStarsData::Instance()->colorScheme()->setStarColorIntensity( i );
 }
 
+void OpsColors::slotDarkAppColors(bool enable)
+{
+    KStarsData::Instance()->colorScheme()->setDarkPalette(enable);
+    KStars::Instance()->loadColorScheme( KStars::Instance()->data()->colorScheme()->fileName());
+}
+
 
