@@ -34,6 +34,8 @@
 #include "ksfilereader.h"
 #include "skylabeler.h"
 #include "kstarsdata.h"
+#include "skymap.h"
+#include "ksnotification.h"
 
 SatellitesComponent::SatellitesComponent( SkyComposite *parent ) :
     SkyComponent( parent )
@@ -99,23 +101,37 @@ void SatellitesComponent::update( KSNumbers * )
 
 void SatellitesComponent::draw( SkyPainter *skyp )
 {
+#ifndef KSTARS_LITE
     // Return if satellites must not be draw
     if( ! selected() )
         return;
 
-    foreach( SatelliteGroup *group, m_groups ) {
-        for ( int i=0; i<group->size(); i++ ) {
+    bool hideLabels =  (!Options::showSatellitesLabels() || ( SkyMap::Instance()->isSlewing() && Options::hideLabels() ));
+
+    foreach( SatelliteGroup *group, m_groups )
+    {
+        for ( int i=0; i<group->size(); i++ )
+        {
             Satellite *sat = group->at( i );
-            if ( sat->selected() ) {
-                if ( Options::showVisibleSatellites() ) {
+            if ( sat->selected() )
+            {
+                bool drawn = false;
+                if ( Options::showVisibleSatellites() )
+                {
                     if ( sat->isVisible() )
-                        skyp->drawSatellite( sat );
-                } else {
-                    skyp->drawSatellite( sat );
+                        drawn = skyp->drawSatellite( sat );
                 }
+                else
+                {
+                    drawn = skyp->drawSatellite( sat );
+                }
+
+                if (drawn && !hideLabels)
+                    SkyLabeler::AddLabel( sat, SkyLabeler::SATELLITE_LABEL );
             }
         }
     }
+#endif
 }
 
 void SatellitesComponent::drawLabel( Satellite *sat, QPointF pos )
@@ -168,22 +184,13 @@ void SatellitesComponent::updateTLEs()
             }
             else
             {
-            #ifndef KSTARS_LITE
-                KMessageBox::error(0, file.errorString());
-            #else
-                qDebug() << file.errorString();
-            #endif
+                KSNotification::error(file.errorString());
                 return;
             }
-
         }
         else
         {
-            #ifndef KSTARS_LITE
-                KMessageBox::error(0, response->errorString());
-            #else
-                qDebug() << response->errorString();
-            #endif
+            KSNotification::error(response->errorString());
             return;
         }
     }
