@@ -111,7 +111,7 @@ public:
     	*@sa updatePlanets()
     	*@sa SolarSystemComposite::updateMoons()
     	*/
-    virtual void updateMoons( KSNumbers *num );
+//    virtual void updateMoons( KSNumbers *num );
 
     /**
     	*@short Delegate draw requests to all sub components
@@ -170,8 +170,9 @@ public:
     void reloadCLines();
     void reloadCNames();
     void reloadConstellationArt();
-
+#ifndef KSTARS_LITE
     FlagComponent* flags();
+#endif
     SatellitesComponent* satellites();
     SupernovaeComponent* supernovaeComponent();
     ArtificialHorizonComponent* artificialHorizon();
@@ -213,7 +214,7 @@ public:
     const QList<SkyObject*>& comets() const;
     const QList<SkyObject*>& supernovae() const;
     QList<SkyObject*> planets();
-    QList<SkyObject*> moons();
+//    QList<SkyObject*> moons();
 
     const QList<SkyObject*> *getSkyObjectsList(SkyObject::TYPE t);
 
@@ -251,7 +252,9 @@ private:
     SolarSystemComposite        *m_SolarSystem;
     SkyComposite                *m_CustomCatalogs;
     StarComponent               *m_Stars;
+#ifndef KSTARS_LITE
     FlagComponent               *m_Flags;
+#endif
     TargetListComponent         *m_ObservingList;
     TargetListComponent         *m_StarHopRouteList;
     SatellitesComponent         *m_Satellites;
