@@ -30,7 +30,9 @@
 #include "kstarsdata.h"
 #include "kstarslite/skyitems/rootnode.h"
 
-#include "basedevice.h"
+#include <basedevice.h>
+
+class DeviceOrientation;
 
 class dms;
 class KStarsData;
@@ -50,11 +52,6 @@ class TelescopeLite;
 class SkyObjectLite;
 class SkyPointLite;
 
-/*class QTapSensor;
-class QMagnetometer;
-class QCompass;
-class QRotationSensor;*/
-
 class QSGTexture;
 
     /** @class SkyMapLite
@@ -87,6 +84,8 @@ class SkyMapLite : public QQuickItem {
      * @short true if SkyMapLite is centered on an object and only pinch-to-zoom needs to be available
     **/
     Q_PROPERTY(bool centerLocked READ getCenterLocked WRITE setCenterLocked NOTIFY centerLockedChanged)
+    Q_PROPERTY(bool automaticMode READ getAutomaticMode WRITE setAutomaticMode NOTIFY automaticModeChanged)
+    Q_PROPERTY(double skyRotation READ getSkyRotation WRITE setSkyRotation NOTIFY skyRotationChanged)
 protected:
     /** Constructor. **/
     explicit SkyMapLite();
@@ -376,6 +375,16 @@ public:
      */
     void setCenterLocked(bool centerLocked);
 
+    /** True if automatic mode is on (SkyMapLite is controled by smartphones accelerometer magnetometer) **/
+    bool getAutomaticMode() const { return m_automaticMode; }
+
+    /**
+     * @short switch automatic mode on/off according to isOn parameter
+     */
+    Q_INVOKABLE void setAutomaticMode(bool automaticMode);
+
+    double getSkyRotation() const { return m_skyRotation; }
+
 public slots:
      /** Called whenever wrappers' width or height are changed. Probably will be used to
      * update positions of items.
@@ -434,11 +443,12 @@ public slots:
      */
     void slotSelectObject(SkyObject *skyObj);
 
-    /**
-     * @short slotGyroMove called when m_gyroSensor got new reading. Moves focus of SkyMapLite according
-     * to coordinates received from gyroscope
-     */
-    //void slotCompassMove();
+#if defined(Q_OS_ANDROID)
+    /** @short updates focus of SkyMapLite according to data from DeviceOrientation
+        (Smartphone's sensors)*/
+    void updateAutomaticMode();
+#endif
+    void setSkyRotation(double skyRotation);
 
 signals:
     /** Emitted by setDestination(), and connected to slewFocus().  Whenever the Destination
@@ -483,6 +493,11 @@ signals:
     void slewingChanged(bool);
 
     void centerLockedChanged(bool);
+
+    void automaticModeChanged(bool);
+
+    /** Emited when skyRotation used to rotate coordinates of SkyPoints is changed **/
+    void skyRotationChanged(double skyRotation);
 protected:
     /** Process keystrokes:
      * @li arrow keys  Slew the map
@@ -684,6 +699,17 @@ private:
 
     QList<INDI::BaseDevice *> m_newTelescopes;
     QList<INDI::BaseDevice *> m_delTelescopes;
+    bool m_automaticMode;
+
+    double m_skyRotation;
+
+    enum class SkyMapOrientation { Top0, Right90, Bottom180, Left270 };
+    SkyMapOrientation m_skyMapOrientation;
+
+#if defined (Q_OS_ANDROID)
+    QTimer automaticModeTimer;
+    DeviceOrientation* m_deviceOrientation;
+#endif
 };
 
 #endif
