@@ -38,8 +38,8 @@ void SkyMapQDraw::paintEvent( QPaintEvent *event ) {
     }
     setDrawLock( true );
 
-    calculateFPS();
-
+    // JM 2016-05-03: Not needed since we're not using OpenGL for now
+    //calculateFPS();
 
     //If computeSkymap is false, then we just refresh the window using the stored sky pixmap
     //and draw the "overlays" on top.  This lets us update the overlay information rapidly
@@ -60,7 +60,7 @@ void SkyMapQDraw::paintEvent( QPaintEvent *event ) {
             return ; // exit because the pixmap is repainted and that's all what we want
         }
 
-    // FIXME: used to to notify infobox about possible change of object coordinates
+    // FIXME: used to notify infobox about possible change of object coordinates
     // Not elegant at all. Should find better option
     m_SkyMap->showFocusCoords();
     m_SkyMap->setupProjector();
