@@ -73,6 +73,8 @@ namespace {
     //
     // These pixmaps are never deallocated. Not really good...
     QPixmap* imageCache[nSPclasses][nStarSizes] = {{0}};
+
+    QPixmap  *visibleSatPixmap=0, *invisibleSatPixmap=0;
 }
 
 int SkyQPainter::starColorMode = 0;
@@ -225,6 +227,9 @@ void SkyQPainter::initStarImages()
         }
     }
     starColorMode = Options::starColorMode();
+
+    visibleSatPixmap = new QPixmap(":/icons/breeze/default/kstars_satellites_visible.svg");
+    invisibleSatPixmap = new QPixmap(":/icons/breeze/default/kstars_satellites_invisible.svg");
 }
 
 void SkyQPainter::drawSkyLine(SkyPoint* a, SkyPoint* b)
@@ -590,7 +595,7 @@ void SkyQPainter::drawDeepSkySymbol(const QPointF &pos, int type, float size, fl
     case 1: //catalog star
         //Some NGC/IC objects are stars...changed their type to 1 (was double star)
         if (size<2.) size = 2.;
-        lambdaDrawEllipse( x1, y1, size/2., size/2. );
+        lambdaDrawEllipse( x - size/2., y - size/2., size, size );
         break;
     case 2: //Planet
         break;
@@ -603,7 +608,7 @@ void SkyQPainter::drawDeepSkySymbol(const QPointF &pos, int type, float size, fl
         if ( size > 50. )  psize *= 2.;
         if ( size > 100. ) psize *= 2.;
         auto putDot = [this, psize, &lambdaDrawEllipse]( float x, float y ) {
-            lambdaDrawEllipse( x, y, psize, psize );
+            lambdaDrawEllipse( x - psize/2., y - psize/2., psize, psize );
         };
         putDot( xa, y1 );
         putDot( xb, y1 );
@@ -772,7 +777,7 @@ void SkyQPainter::drawFlags()
 
         // Draw flag label
         setPen( data->skyComposite()->flags()->labelColor( i ) );
-        setFont( QFont( "Courier New", 10, QFont::Bold ) );
+        setFont( QFont( "Helvetica", 10, QFont::Bold ) );
         drawText( pos.x()+10, pos.y()-10, data->skyComposite()->flags()->label( i ) );
     }
 }
@@ -793,34 +798,43 @@ void SkyQPainter::drawHorizon(bool filled, SkyPoint* labelPoint, bool* drawLabel
     }
 }
 
-void SkyQPainter::drawSatellite( Satellite* sat ) {
-    KStarsData *data = KStarsData::Instance();
+bool SkyQPainter::drawSatellite( Satellite* sat )
+{
+    if( !m_proj->checkVisibility(sat) )
+        return false;
+
     QPointF pos;
     bool visible = false;
 
-    sat->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
+    //sat->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
 
     pos = m_proj->toScreen( sat, true, &visible );
 
     if( !visible || !m_proj->onScreen( pos ) )
-        return;
+        return false;
 
-    if ( Options::drawSatellitesLikeStars() ) {
+    if ( Options::drawSatellitesLikeStars() )
+    {
         drawPointSource(pos, 3.5, 'B');
-    } else {
+    }
+    else
+    {
         if ( sat->isVisible() )
-            setPen( data->colorScheme()->colorNamed( "VisibleSatColor" ) );
+            drawPixmap(QPoint( pos.x() - 15, pos.y() - 11 ), *visibleSatPixmap);
         else
-            setPen( data->colorScheme()->colorNamed( "SatColor" ) );
+            drawPixmap(QPoint( pos.x() - 15, pos.y() - 11 ), *invisibleSatPixmap);
 
-        drawLine( QPoint( pos.x() - 0.5, pos.y() - 0.5 ), QPoint( pos.x() + 0.5, pos.y() - 0.5 ) );
+        //drawPixmap(pos, *genericSatPixmap);
+        /*drawLine( QPoint( pos.x() - 0.5, pos.y() - 0.5 ), QPoint( pos.x() + 0.5, pos.y() - 0.5 ) );
         drawLine( QPoint( pos.x() + 0.5, pos.y() - 0.5 ), QPoint( pos.x() + 0.5, pos.y() + 0.5 ) );
         drawLine( QPoint( pos.x() + 0.5, pos.y() + 0.5 ), QPoint( pos.x() - 0.5, pos.y() + 0.5 ) );
-        drawLine( QPoint( pos.x() - 0.5, pos.y() + 0.5 ), QPoint( pos.x() - 0.5, pos.y() - 0.5 ) );
+        drawLine( QPoint( pos.x() - 0.5, pos.y() + 0.5 ), QPoint( pos.x() - 0.5, pos.y() - 0.5 ) );*/
     }
 
-    if ( Options::showSatellitesLabels() )
-        data->skyComposite()->satellites()->drawLabel( sat, pos );
+    return true;
+
+    //if ( Options::showSatellitesLabels() )
+        //data->skyComposite()->satellites()->drawLabel( sat, pos );
 }
 
 bool SkyQPainter::drawSupernova(Supernova* sup)
